@@ -211,7 +211,6 @@ class XhotkeysServer:
 		"""Set hotkeys and hotbuttons from the current table"""
 		mode = Xlib.X.GrabModeAsync
 		
-		# I don't know why, but events are received even without calling change_attributes...
 		self.root.change_attributes(event_mask=Xlib.X.KeyPressMask | Xlib.X.ButtonPressMask)
 		for comb in self.combinations:
 			if not comb["keycode"]: continue
@@ -759,7 +758,7 @@ class Xhotkeys:
 	def on_browse_clicked(self, widget):
 		self.widgets["filechooser"] = gtk.FileChooserDialog()
 		self.widgets["filechooser"].connect("file-activated", self.filechooser_file)
-		self.widgets["filechooser"].show()
+		self.widgets["filechooser"].run()
 
 	#########################################
 	def on_name_changed(self, widget):
@@ -899,8 +898,8 @@ class Xhotkeys:
 		# Enable dragging desktop files to table
 		mime_list = [ ( 'text/uri-list', 0, TARGET_TYPE_URI_LIST ), ('xhotkeys/row', gtk.TARGET_SAME_WIDGET, 0) ]
 		treeview.enable_model_drag_source(gtk.gdk.BUTTON1_MASK, \
-			[('xhotkeys/row', gtk.TARGET_SAME_WIDGET, 0)], gtk.gdk.ACTION_COPY)
-		treeview.enable_model_drag_dest(mime_list, gtk.gdk.ACTION_COPY)
+			[('xhotkeys/row', gtk.TARGET_SAME_WIDGET, 0)], gtk.gdk.ACTION_MOVE)
+		treeview.enable_model_drag_dest(mime_list, gtk.gdk.ACTION_MOVE)
 
 	#####################################################
 	def save_settings(self):
